@@ -349,7 +349,9 @@ def read_airr(
      * at least one of `junction_aa` or `junction`.
 
     Data should still import if one of these fields is missing, but they are required
-    by most of scirpy's processing functions. 
+    by most of scirpy's processing functions. All chains for which the field
+    `junction_aa` is missing or empty, will be considered as non-productive and 
+    will be moved to the `extra_chains` column.   
 
     {doc_working_model}
 
@@ -661,10 +663,12 @@ def to_dandelion(adata: AnnData):
 
 
 @_doc_params(doc_working_model=doc_working_model)
-def from_dandelion(dandelion, transfer=False) -> AnnData:
+def from_dandelion(dandelion, transfer: bool = False, **kwargs) -> AnnData:
     """\
     Import data from `Dandelion <https://github.com/zktuong/dandelion>`_ (:cite:`Stephenson2021`).
 
+    Internally calls :func:`scirpy.io.read_airr`. 
+
     {doc_working_model}
 
     Parameters
@@ -674,6 +678,8 @@ def from_dandelion(dandelion, transfer=False) -> AnnData:
     transfer
         Whether to execute `dandelion.tl.transfer` to transfer all data
         to the :class:`anndata.AnnData` instance.
+    **kwargs
+        Additional arguments passed to :func:`scirpy.io.read_airr`. 
 
     Returns
     -------
@@ -689,7 +695,8 @@ def from_dandelion(dandelion, transfer=False) -> AnnData:
     for col in dandelion_df.columns:
         dandelion_df.loc[dandelion_df[col] == "unassigned", col] = None
 
-    adata = read_airr(dandelion_df)
+    adata = read_airr(dandelion_df, **kwargs)
+
     if transfer:
         ddl.tl.transfer(
             adata, dandelion
