@@ -267,19 +267,98 @@ def test_clonal_expansion_summary(adata_clonotype):
     )
 
 
+@pytest.mark.extra
 def test_alpha_diversity(adata_diversity):
+    # normalized_shannon_entropy by default
     res = ir.tl.alpha_diversity(
         adata_diversity, groupby="group", target_col="clonotype_", inplace=False
     )
     assert res.to_dict(orient="index") == {"A": {0: 0.0}, "B": {0: 1.0}}
 
+    # D50
+    res = ir.tl.alpha_diversity(
+        adata_diversity,
+        groupby="group",
+        target_col="clonotype_",
+        metric="D50",
+        inplace=False,
+    )
+    assert res.to_dict(orient="index") == {"A": {0: 100.0}, "B": {0: 50.0}}
+
+    # observed_otus from skbio.diversity.alpha that calculates the number of distinct OTUs.
+    res = ir.tl.alpha_diversity(
+        adata_diversity,
+        groupby="group",
+        target_col="clonotype_",
+        metric="observed_otus",
+        inplace=False,
+    )
+    assert res.to_dict(orient="index") == {"A": {0: 1}, "B": {0: 4}}
+
+    # custom metric function simply returns the # of unique clonotypes,
+    # same as the observed_otus function
+    def metric_func(counts):
+        return len(counts)
+
+    res = ir.tl.alpha_diversity(
+        adata_diversity,
+        groupby="group",
+        target_col="clonotype_",
+        metric=metric_func,
+        inplace=False,
+    )
+    assert res.to_dict(orient="index") == {"A": {0: 1}, "B": {0: 4}}
+
     ir.tl.alpha_diversity(
         adata_diversity, groupby="group", target_col="clonotype_", inplace=True
     )
+    ir.tl.alpha_diversity(
+        adata_diversity,
+        groupby="group",
+        target_col="clonotype_",
+        metric="D50",
+        inplace=True,
+    )
+    ir.tl.alpha_diversity(
+        adata_diversity,
+        groupby="group",
+        target_col="clonotype_",
+        metric="observed_otus",
+        inplace=True,
+    )
+
+    ir.tl.alpha_diversity(
+        adata_diversity,
+        groupby="group",
+        target_col="clonotype_",
+        metric="observed_otus",
+        inplace=True,
+    )
+
+    ir.tl.alpha_diversity(
+        adata_diversity,
+        groupby="group",
+        target_col="clonotype_",
+        metric=metric_func,
+        inplace=True,
+    )
+
     npt.assert_equal(
-        adata_diversity.obs["alpha_diversity_clonotype_"].values,
+        adata_diversity.obs["normalized_shannon_entropy_clonotype_"].values,
         np.array([0.0] * 4 + [1.0] * 4),
     )
+    npt.assert_equal(
+        adata_diversity.obs["D50_clonotype_"].values,
+        np.array([100.0] * 4 + [50.0] * 4),
+    )
+    npt.assert_equal(
+        adata_diversity.obs["observed_otus_clonotype_"].values,
+        np.array([1] * 4 + [4] * 4),
+    )
+    npt.assert_equal(
+        adata_diversity.obs["metric_func_clonotype_"].values,
+        np.array([1] * 4 + [4] * 4),
+    )
 
 
 def test_group_abundance():
